@@ -1,17 +1,18 @@
 @testable import {{ project }}
-import XCTest
 import Reusable
+import UIKit
+import XCTest
 
 final class {{ name }}ViewControllerTests: XCTestCase {
     var viewController: {{ name }}ViewController!
 
     override func setUp() {
         super.setUp()
-        viewController = {{ name }}ViewController.instantiate()
+//        viewController = {{ name }}ViewController.instantiate()
     }
 
     func test_ibOutlets() {
-        _ = viewController.view
+//        _ = viewController.view
 //        XCTAssertNotNil(viewController.tableView)
     }
 }
