@@ -1,18 +1,19 @@
 @testable import {{ project }}
-import XCTest
+import RxCocoa
 import RxSwift
-import RxBlocking
+import XCTest
 
 final class {{ name }}ViewModelTests: XCTestCase {
     private var viewModel: {{ name }}ViewModel!
     private var navigator: {{ name }}NavigatorMock!
     private var useCase: {{ name }}UseCaseMock!
-    
     private var input: {{ name }}ViewModel.Input!
     private var output: {{ name }}ViewModel.Output!
-
     private var disposeBag: DisposeBag!
 
+    // Triggers
+    // private let loadTrigger = PublishSubject<Void>()
+
     override func setUp() {
         super.setUp()
         navigator = {{ name }}NavigatorMock()
@@ -20,8 +21,7 @@ final class {{ name }}ViewModelTests: XCTestCase {
         viewModel = {{ name }}ViewModel(navigator: navigator, useCase: useCase)
 
         input = {{ name }}ViewModel.Input()
-        output = viewModel.transform(input)
-
         disposeBag = DisposeBag()
+        output = viewModel.transform(input, disposeBag: disposeBag)
     }
 }
