@@ -2,7 +2,7 @@ extension {{ name }} {
     init() {
         self.init(
         {% for p in properties %}
-            {{ p.name }}: {{ p.value }}{{ "," if not loop.last }}
+            {{ p.name }}: {{ p.type.default_value }}{{ "," if not loop.last }}
         {% endfor %}
         )
     }
