@@ -1,47 +1,41 @@
 @testable import {{ project }}
-import XCTest
 import RxSwift
-import RxBlocking
+import XCTest
 
 final class {{ name }}ViewModelTests: XCTestCase {
     private var viewModel: {{ name }}ViewModel!
     private var navigator: {{ name }}NavigatorMock!
     private var useCase: {{ name }}UseCaseMock!
-    
     private var input: {{ name }}ViewModel.Input!
     private var output: {{ name }}ViewModel.Output!
-
     private var disposeBag: DisposeBag!
+    private var {{ model_variable }}: {{ model_name }}!
 
+    // Triggers
     private let loadTrigger = PublishSubject<Void>()
 
     override func setUp() {
         super.setUp()
         navigator = {{ name }}NavigatorMock()
         useCase = {{ name }}UseCaseMock()
-        viewModel = {{ name }}ViewModel(navigator: navigator, useCase: useCase, {{ model_variable }}: {{ model_name }}())
+        {{ model_variable }} = {{ model_name }}()
+        viewModel = {{ name }}ViewModel(navigator: navigator, useCase: useCase, {{ model_variable }}: {{ model_variable }})
 
         input = {{ name }}ViewModel.Input(
             loadTrigger: loadTrigger.asDriverOnErrorJustComplete()
         )
 
-        output = viewModel.transform(input)
-
         disposeBag = DisposeBag()
-        
-    {% for p in properties %}
-        output.{{ p.name }}.drive().disposed(by: disposeBag)
-    {% endfor %}
+        output = viewModel.transform(input, disposeBag: disposeBag)
     }
 
-    func test_loadTriggerInvoked_createCells() {
+    func test_loadTrigger_{{ model_variable }}() {
         // act
         loadTrigger.onNext(())
-    {% for p in properties %}
-        let {{ p.name }} = try? output.{{ p.name }}.toBlocking(timeout: 1).first()
-    {% endfor %}
         
         // assert
-        XCTAssert(true)
+        {% for p in properties %}
+        XCTAssertEqual(output.{{ p.name }}, {{ model_variable }}.{{ p.name }})
+        {% endfor %}
     }
 }
