@@ -7,11 +7,11 @@ final class {{ name }}ViewControllerTests: XCTestCase {
 
     override func setUp() {
         super.setUp()
-        viewController = {{ name }}ViewController.instantiate()
+//        viewController = {{ name }}ViewController.instantiate()
     }
 
     func test_ibOutlets() {
-        _ = viewController.view
-        XCTAssertNotNil(viewController.tableView)
+//        _ = viewController.view
+//        XCTAssertNotNil(viewController.tableView)
     }
 }
