@@ -1,19 +1,19 @@
 @testable import {{ project }}
-import XCTest
 import Reusable
+import XCTest
 
 final class {{ name }}ViewControllerTests: XCTestCase {
     var viewController: {{ name }}ViewController!
 
     override func setUp() {
         super.setUp()
-        viewController = {{ name }}ViewController.instantiate()
+//        viewController = {{ name }}ViewController.instantiate()
     }
 
     func test_ibOutlets() {
-        _ = viewController.view
-        XCTAssertNotNil(viewController.tableView)
-        XCTAssertNotNil(viewController.cancelButton)
-        XCTAssertNotNil(viewController.{{ submit }}Button)
+//        _ = viewController.view
+//        XCTAssertNotNil(viewController.tableView)
+//        XCTAssertNotNil(viewController.cancelButton)
+//        XCTAssertNotNil(viewController.{{ submit }}Button)
     }
 }
\ No newline at end of file
