@@ -8,17 +8,17 @@ final class {{ name }}ViewControllerTests: XCTestCase {
 
     override func setUp() {
         super.setUp()
-        viewController = {{ name }}ViewController.instantiate()
+//        viewController = {{ name }}ViewController.instantiate()
     }
 
     func test_ibOutlets() {
-        _ = viewController.view
-        XCTAssertNotNil(viewController.tableView)
-        XCTAssertNotNil(viewController.cancelButton)
-        XCTAssertNotNil(viewController.{{ submit }}Button)
+//        _ = viewController.view
+//        XCTAssertNotNil(viewController.tableView)
+//        XCTAssertNotNil(viewController.cancelButton)
+//        XCTAssertNotNil(viewController.{{ submit }}Button)
         {% for p in properties %}
         {% if p.type.name == 'String' %}
-        XCTAssertNotNil(viewController.{{ p.name }}TextField)
+//        XCTAssertNotNil(viewController.{{ p.name }}TextField)
         {% endif %}
         {% endfor %}
     }
