@@ -1,3 +1,6 @@
+import MGArchitecture
+import RxSwift
+
 protocol {{ name }}UseCaseType {
     {% if paging %}
     func get{{ model_name }}List(page: Int) -> Observable<PagingInfo<{{ model_name }}>>
